@@ -1,11 +1,20 @@
-from pathlib import Path
+# noqa: E402
+import os
+import sys
 
-import numpy as np
-import pytest
+if os.environ.get("CI", False):
+    # remove the local version from sys.path so that we use the version
+    # we installed from the wheel
+    sys.path = sys.path[1:]
 
-import fast_overlap
+from pathlib import Path  # noqa: E402
 
-ims = np.load(str(Path(__file__).parent / "test-ims.npy"))
+import numpy as np  # noqa: E402
+import pytest  # noqa: E402
+
+import fast_overlap  # noqa: E402
+
+ims = np.load(str(Path(__file__).parent / "test-ims.npy")).astype(np.int64)
 expected = np.load(str(Path(__file__).parent / "expected-overlap.npy"))
 shape = (int(np.max(ims[0]) + 1), int(np.max(ims[1]) + 1))
 
@@ -17,6 +26,11 @@ def test_overlap(type):
     assert np.all(out == expected)
 
 
+def test_overlap_no_shape():
+    out = fast_overlap.overlap(ims[0], ims[1])
+    assert np.all(out == expected)
+
+
 def test_parallel_overlap():
     out = fast_overlap.overlap_parallel(
         ims[0].astype(np.int32), ims[1].astype(np.int32), shape
